@@ -1,31 +1,19 @@
 /*  This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2016 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2016 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KLEO_KEYSELECTIONCOMBO_H
-#define KLEO_KEYSELECTIONCOMBO_H
+#pragma once
+
+#include "kleo_export.h"
+
+#include <Libkleo/Enum>
 
 #include <QComboBox>
 
 #include <gpgme++/global.h>
 
-#include <kleo_export.h>
-#include <libkleo/enum.h>
-
 #include <memory>
 
 namespace GpgME
@@ -68,6 +56,7 @@ public:
     void appendCustomItem(const QIcon &icon, const QString &text, const QVariant &data);
     void prependCustomItem(const QIcon &icon, const QString &text, const QVariant &data, const QString &toolTip);
     void appendCustomItem(const QIcon &icon, const QString &text, const QVariant &data, const QString &toolTip);
+    void removeCustomItem(const QVariant &data);
 
 Q_SIGNALS:
     void customItemSelected(const QVariant &data);
@@ -78,8 +67,7 @@ protected:
     virtual void init();
 
 private:
-    KeySelectionComboPrivate * const d;
+    std::unique_ptr<KeySelectionComboPrivate> const d;
 };
 
 }
-#endif
